from fastapi import APIRouter, Depends, HTTPException

from ..di import get_user_service
from ..schemas import UserReadDTO
from ..schemas.user_schema import UserWriteDTO
from ..services import UserService

router = APIRouter()


@router.get("/users", response_model=list[UserReadDTO])
async def get_user_list(
    user_service: UserService = Depends(get_user_service),
) -> list[UserReadDTO]:
    return await user_service.get_all_users()


@router.post("/users", response_model=UserReadDTO)
async def add_user(
    data: UserWriteDTO,
    user_service: UserService = Depends(get_user_service),
) -> UserReadDTO:
    res = await user_service.add_one(data)
    if not isinstance(res, UserReadDTO):
        raise HTTPException(status_code=400, detail=res)
    return res


@router.get("/status")
def get_status():
    return {"status": "OK"}
