from sqlalchemy.exc import IntegrityError

from ..schemas.user_schema import UserWriteDTO
from ..uow.uow_base import UnitOfWork


class UserService:
    def __init__(self, uow: UnitOfWork):
        self.uow = uow

    async def get_all_users(self):
        async with self.uow:
            res = await self.uow.users.find_all()

        return res

    async def add_one(self, data: UserWriteDTO):
        res = None
        async with self.uow:
            try:
                res = await self.uow.users.add_one(data)
            except IntegrityError as e:
                await self.uow.rollback()
                res = e._message()
            else:
                await self.uow.commit()
            finally:
                return res
